@@ -585,13 +585,13 @@ export default class EsQueryObserver extends EsQueryEvaluator{
 
         //Observe segments
         var res = null;    
-        res = await this.EvalOnContextAndScope(context,args[2],context,eoqHistory,(res) => {
-            let condition=EvalOnContextAndScope(context,args[1],context,eoqHistory);
+        res = await this.EvalOnContextAndScope(context,args[2],context,eoqHistory,async (res) => {
+            let condition=await EvalOnContextAndScope(context,args[1],context,eoqHistory);
             if(condition) callback(res);
         })
     
-        res = await this.EvalOnContextAndScope(context,args[3],context,eoqHistory,(res) => {
-            let condition=EvalOnContextAndScope(context,args[1],context,eoqHistory);
+        res = await this.EvalOnContextAndScope(context,args[3],context,eoqHistory,async (res) => {
+            let condition=await EvalOnContextAndScope(context,args[1],context,eoqHistory);
             if(!condition) callback(res);
         })
         
